/* ------------------------------------------------------------------------------------------------ */
/* FILE :		uAbassiCfg.c																		*/
/*																									*/
/* CONTENTS :																						*/
/*				Configuration file for uAbassi														*/
/*																									*/
/*																									*/
/* Copyright (c) 2014-2019, Code-Time Technologies Inc. All rights reserved.						*/
/*																									*/
/* Code-Time Technologies retains all right, title, and interest in and to this work				*/
/*																									*/
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS							*/
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF										*/
/* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL							*/
/* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR								*/
/* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,							*/
/* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR							*/
/* OTHER DEALINGS IN THE SOFTWARE.																	*/
/*																									*/
/*																									*/
/*	$Revision: 1.2 $																				*/
/*	$Date: 2019/01/10 18:07:13 $																	*/
/*																									*/
/* ------------------------------------------------------------------------------------------------ */
/*																									*/
/* Contains the following configuration for uAbassi													*/
/*																									*/
/*	Type of multi-processing:																		*/
/*		G_OS_MP_TYPE     = 2U true SMP																*/
/*		                 = 3U packed SMP															*/
/*		                 = 4U true BMP																*/
/*		                 = 5U packed BMP															*/
/*																									*/
/*		G_OS_START_STACK = Stack size (bytes) of the Idle Core tasks (when no task run on a core)	*/
/*																									*/
/*		G_OS_TIMER_US    = Timer tick in us (only used for sec <--> tick conversion macros			*/
/*																									*/
/*  MMU / Cache defintion tables																	*/
/*																									*/
/* ------------------------------------------------------------------------------------------------ */

#include "uAbassi.h"

/* This allows the app to define MP_TYPE & START_STACK with the regular mAbassi build options		*/

#ifndef OS_MP_TYPE
  #define OS_MP_TYPE		4U						/* If not def in build, set desired value here	*/
#endif
#ifndef OS_START_STACK
  #define OS_START_STACK	16384					/* If not def in build, set desired value here	*/
#endif

/* ------------------------------------------------------------------------------------------------ */
/* This macro is used to define the stack size and the stack memory itslef as needed by uAbassi		*/
/* start-up code.																					*/
/* The macro arguments are:																			*/
/* Mode : Stack for the indicated processor "Mode".  All following modes must be defined:			*/
/*			        	ABORT, FIQ, IRQ, SUPER, UNDEF												*/
/* Size : Size in bytes of the stack allocated for each core.										*/
/*        It is not possible to set different stack sizes between the cores.						*/
/* ------------------------------------------------------------------------------------------------ */

#define DEF_MODE_STACK_SIZE(Mode, Size)																\
				const int G_ ## Mode ## stackSize = (OX_N_CORE) * (Size);							\
				OSalign_t G_ ## Mode ## stack      [(OX_N_CORE) * ((Size)/sizeof(OSalign_t))]

/* ------------------------------------------------------------------------------------------------ */

const unsigned int G_OS_MP_TYPE   = OS_MP_TYPE;		/* Type of multi-processing. See documentation	*/
const int        G_OS_START_STACK = OS_START_STACK;	/* Stack size in bytes of each CoreIdle tasks	*/
const int        G_OS_TIMER_US    = OS_TIMER_US;	/* Application specific value					*/

DEF_MODE_STACK_SIZE(ABORT, 1024);					/* Abort mode stack defintions					*/
DEF_MODE_STACK_SIZE(FIQ,   1024);					/* FIQ mode stack defintions					*/
DEF_MODE_STACK_SIZE(IRQ,   16384);					/* IRQ mode stack defintions					*/
DEF_MODE_STACK_SIZE(SUPER, 16384);					/* Supervisor mode stack defintions				*/
DEF_MODE_STACK_SIZE(UNDEF, 1024);					/* Undefined mode stack defintions				*/

#if ((OS_PLATFORM) != 0xFEE6)						/* iMX6 is using hard coded MMU tables			*/
  #if (((OS_DEMO) != 50) && ((OS_DEMO) != -50))
													/* MMU table definitions. See documentation		*/
/*                                          LENGTH      BASE ADDR									*/
const unsigned int G_MMUsharedTbl[]    = { 0x40000000, 0x00000000,
                                           0
                                         };
const unsigned int G_MMUnonCachedTbl[] = { 0xC0000000, 0x40000000,
                                           0
                                         };
/*											LENGTH      VIRT ADDR    PHYS ADDR						*/
const unsigned int G_MMUprivateTbl[]   = { 0,
                                           0
                                         };
const unsigned int G_MMUnonCprivTbl[]  = { 0,
                                           0
                                         };
  #endif

#else														/* i.MX6								*/
  #if (((OS_DEMO) != 50) && ((OS_DEMO) != -50))
													/* MMU table definitions. See documentation		*/
/*                                          LENGTH      BASE ADDR									*/
const unsigned int G_MMUsharedTbl[]    = { 0xF0000000, 0x10000000,
                                           0
                                         };
const unsigned int G_MMUnonCachedTbl[] = { 0x10000000, 0x00000000,
                                           0
                                         };
/*											LENGTH      VIRT ADDR    PHYS ADDR						*/
const unsigned int G_MMUprivateTbl[]   = { 0,
                                           0,
                                           0,
                                           0				/* 4 zeros (none) when is 4 cores		*/
                                         };					/* Superfluous 2 zeroes when is 2 cores	*/
const unsigned int G_MMUnonCprivTbl[]  = { 0,
                                           0,
                                           0,
                                           0				/* 4 zeros (none) when is 4 cores		*/
                                         };					/* Superfluous 2 zeroes when is 2 cores	*/
  #endif

#endif

/* EOF */
