/* ------------------------------------------------------------------------------------------------ */
/* FILE :		BareMetalApps.c																		*/
/*																									*/
/* CONTENTS :																						*/
/*				Example code for bare-metal applications using the custom version of				*/
/*				uAbassi.																			*/
/*				This file contains the bare-metal code itself - the code is identical as running	*/
/*				"Hello World" on each cores, except it shows which core the printf() occurs.		*/
/*				The infinite loop is paused, and each app uses a different pause time from others.	*/
/*				All the apps are located here to simplify the build. You will likely prefer using	*/
/*				individual files for your applications.												*/
/*				Make sure the size of the stack allocated for each core is big enough - this is		*/
/*				set int TSKcreate() in the BareMetal.c file.										*/
/*				If different names than App_# are desired, change the name of the functions in 		*/
/*				TSKcreate() in the BareMetal.c file.												*/
/*																									*/
/* IMPORTANT:																						*/
/*				The maximum number of tasks that can be created is ths same as the number of cores	*/
/*				on the target platform.  The maximum number of semaphores that can be created is 	*/
/*				set to 64 and this provides morte than plenty of semaphores to use in Code Time's	*/
/*				multi-thread-safe and multicore-safe drivers.										*/
/*				The number of mutexes that can be created is only limited by the size of the heap	*/
/*				memory, i.e. the memory available using malloc().									*/
/*				The number of spinlocks (CORElock() and COREunlock()) is unlimited.					*/
/*																									*/
/* Copyright (c) 2017-2019, Code-Time Technologies Inc. All rights reserved.						*/
/*																									*/
/* Code-Time Technologies retains all right, title, and interest in and to this work				*/
/*																									*/
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS							*/
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF										*/
/* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL							*/
/* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR								*/
/* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,							*/
/* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR							*/
/* OTHER DEALINGS IN THE SOFTWARE.																	*/
/*																									*/
/*																									*/
/*	$Revision: 1.7 $																				*/
/*	$Date: 2019/02/19 01:02:04 $																	*/
/*																									*/
/* ------------------------------------------------------------------------------------------------ */

#include "uAbassi.h"								/* This file must always be included			*/
													/* These 2 includes are not used in this demo	*/
#include "Platform.h"								/* Everything about the target platform is here	*/
#include "HWinfo.h"									/* Everything about the target hardware is here	*/

int PRINTF(const char *Str, ...);					/* Excluive access protected printf()			*/

/* ------------------------------------------------------------------------------------------------ */
/* Application code running on core #0																*/

void App_0(void)
{

	for(;;) {

		TSKsleep(OS_MS_TO_TICK(101));				/* Pace the message printed to stdout			*/

		PRINTF("App_0 running on core #%d\n", COREgetID());
	}
}

/* ------------------------------------------------------------------------------------------------ */
/* Application code running on core #1																*/

void App_1(void)
{

	for(;;) {

		TSKsleep(OS_MS_TO_TICK(113));				/* Pace the message printed to stdout			*/

		PRINTF("App_1 running on core #%d\n", COREgetID());
	}
}

/* ------------------------------------------------------------------------------------------------ */
/* Application code running on core #2																*/
/* Not used when the target platform has 2 cores or less											*/

#if ((OS_N_CORE) > 2)

void App_2(void)
{

	for(;;) {

		TSKsleep(OS_MS_TO_TICK(127));				/* Pace the message printed to stdout			*/

		PRINTF("App_2 running on core #%d\n", COREgetID());
	}
}

#endif

/* ------------------------------------------------------------------------------------------------ */
/* Application code running on core #3																*/
/* Not used when the target platform has 3 cores or less											*/

#if ((OS_N_CORE) > 3)

void App_3(void)
{

	for(;;) {

		TSKsleep(OS_MS_TO_TICK(137));				/* Pace the message printed to stdout			*/

		PRINTF("App_3 running on core #%d\n", COREgetID());
	}
}

#endif

/* ------------------------------------------------------------------------------------------------ */
/* Replacement for printf() to provide exclusive access to the printf() facilities					*/
/*																									*/
/* The mutex could be opened once (created) if desired.  It is opened every time to demonstrate the	*/
/* the runtime-safe service creation feature of uAbassi.											*/

int PRINTF(const char *Str, ...)
{
MTX_t  *PrtMtx;										/* printf() mutex for exclusive access			*/
int     RetVal;										/* Return value from vprintf()					*/
va_list Varg;										/* Variable argument state						*/


	va_start(Varg, Str);							/* Beginning of variable lentgth arguments		*/

	PrtMtx = MTXopen("Printf Mtx");					/* If the mutex does not exists it will be		*/
													/* created, otherwise get the existing mutex	*/
	MTXlock(PrtMtx, -1);							/* Protect the accesses to printf()				*/

	RetVal = vprintf(Str, Varg);					/* Muat use vprintf() instead of printf()		*/

	MTXunlock(PrtMtx);								/* Need for exclusive access protection is over	*/

	va_end(Varg);									/* End of variable lentgth arguments			*/

	return(RetVal);
}
	
/* EOF */
